==> haskell-lrucache-1.2.0.1-5-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-lrucache.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: lrucache
version: 1.2.0.1
id: lrucache-1.2.0.1-2ZAft0KMYCLF1rrBHLdOAx
key: lrucache-1.2.0.1-2ZAft0KMYCLF1rrBHLdOAx
license: BSD-3-Clause
copyright: Carl Howells, 2010-2015
maintainer: chowells79@gmail.com
author: Carl Howells
stability: Experimental
homepage: http://github.com/chowells79/lrucache
synopsis: a simple, pure LRU cache
description:
    This package contains a simple, pure LRU cache, implemented in
    terms of "Data.Map".
    .
    It also contains a mutable IO wrapper providing atomic updates to
    an LRU cache.
category: Data
abi: 377760e6dc3e3202a20523d61b388398
exposed: True
exposed-modules:
    Data.Cache.LRU Data.Cache.LRU.IO Data.Cache.LRU.IO.Internal
    Data.Cache.LRU.Internal
import-dirs: /usr/lib/ghc-8.6.5/site-local/lrucache-1.2.0.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/lrucache-1.2.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/lrucache-1.2.0.1
hs-libraries: HSlrucache-1.2.0.1-2ZAft0KMYCLF1rrBHLdOAx
depends:
    base-4.12.0.0 containers-0.6.0.1
    contravariant-1.5.1-AvnIJSQPha7KTZETo8YECh
haddock-interfaces: /usr/share/doc/haskell-lrucache/html/lrucache.haddock
haddock-html: /usr/share/doc/haskell-lrucache/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-lrucache-1.2.0.1-6-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-lrucache.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: lrucache
version: 1.2.0.1
id: lrucache-1.2.0.1-Jp0V4IWXx2qKkaEspf8xgI
key: lrucache-1.2.0.1-Jp0V4IWXx2qKkaEspf8xgI
license: BSD-3-Clause
copyright: Carl Howells, 2010-2015
maintainer: chowells79@gmail.com
author: Carl Howells
stability: Experimental
homepage: http://github.com/chowells79/lrucache
synopsis: a simple, pure LRU cache
description:
    This package contains a simple, pure LRU cache, implemented in
    terms of "Data.Map".
    .
    It also contains a mutable IO wrapper providing atomic updates to
    an LRU cache.
category: Data
abi: f9c518a705f91ed744993dd954d7fb28
exposed: True
exposed-modules:
    Data.Cache.LRU Data.Cache.LRU.IO Data.Cache.LRU.IO.Internal
    Data.Cache.LRU.Internal
import-dirs: /usr/lib/ghc-8.6.5/site-local/lrucache-1.2.0.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/lrucache-1.2.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/lrucache-1.2.0.1
hs-libraries: HSlrucache-1.2.0.1-Jp0V4IWXx2qKkaEspf8xgI
depends:
    base-4.12.0.0 containers-0.6.0.1
    contravariant-1.5.2-IGTyLqhZC2pCTY0qng5HHQ
haddock-interfaces: /usr/share/doc/haskell-lrucache/html/lrucache.haddock
haddock-html: /usr/share/doc/haskell-lrucache/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
